#ifndef NT2_INCLUDE_FUNCTIONS_COV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COV_HPP_INCLUDED

#include <nt2/linalg/include/functions/cov.hpp>

#endif
